#!/bin/bash

FILE="3.1.xml"

function die {
  echo "ERROR: $@"
  exit 1
}

function check_file {
  [[ -f "$1" ]] || die "FILE '$1' not found"
}

function strip {
  s=$(cat)
  s=${s## }
  echo ${s%% }
}

check_file "$FILE"

xmllint --version 2> /dev/null || die "xmllint not found. Please install it."
xsltproc --version > /dev/null || die "xsltproc not found. Please install it."

xmllint --noout "$FILE" || die "File '$FILE' is not a valid XML file."
echo "Test 0 PASSED: '$FILE' is a valid XML file."

check_file "3.1.test1.xslt"
ROOT=$(xsltproc 3.1.test1.xslt "$FILE") || die "Error in '$FILE'"
[[ "$ROOT" = "ecole" ]] || die "Expected one root element <ecole> in '$FILE'"
echo "Test 1 PASSED: '$FILE' has a root element <ecole>."

xmllint --noout --dtdvalid 3.1.dtd "$FILE" \
  || die "File '$FILE' does not correspond to the DTD."
echo "Test 2 PASSED: '$FILE' corresponds to the DTD"

NUM=$(grep -c "<annee " "$FILE" | strip)
(( NUM >= 2 )) || die "File '$FILE' has less than 2 elements <annee>."
echo "Test 3 PASSED: '$FILE' has at least two <annee>."

NUM=$(xsltproc 3.1.test2.xslt "$FILE" | grep "@645321@" | sort -u | wc -l | strip)
(( NUM >= 2 )) || die "File '$FILE' uses only one value for the 'bloc' attribute."
echo "Test 4 PASSED: '$FILE' has at least two 'bloc' attributes with different values."

echo "SUCCESS"
